@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: textsplit.cpp,v 1.36 2007/12/13 06:58:21 dockes Exp $ (C) 2004 J.F.Dockes";
+static char rcsid[] = "@(#$Id: textsplit.cpp,v 1.38 2008-12-12 11:53:45 dockes Exp $ (C) 2004 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -59,6 +59,7 @@ enum CharClass {LETTER=256, SPACE=257, DIGIT=258, WILD=259};
 static int charclasses[256];
 
 static set<unsigned int> unicign;
+static set<unsigned int> visiblewhite;
 static void setcharclasses()
 {
     static int init = 0;
@@ -87,14 +88,19 @@ static void setcharclasses()
     for (i = 0; i  < strlen(wild); i++)
 	charclasses[int(wild[i])] = WILD;
 
-    char special[] = ".@+-,#'\n\r";
+    char special[] = ".@+-,#'_\n\r";
     for (i = 0; i  < strlen(special); i++)
 	charclasses[int(special[i])] = special[i];
 
-    for (i = 0; i < sizeof(uniign); i++) 
+    for (i = 0; i < sizeof(uniign) / sizeof(int); i++) {
 	unicign.insert(uniign[i]);
+    }
     unicign.insert((unsigned int)-1);
 
+    for (i = 0; i < sizeof(avsbwht) / sizeof(int); i++) {
+	visiblewhite.insert(avsbwht[i]);
+    }
+
     init = 1;
 }
 
@@ -132,16 +138,23 @@ static inline int whatcc(unsigned int c)
 // FF00..FFEF; Halfwidth and Fullwidth Forms
 // 20000..2A6DF; CJK Unified Ideographs Extension B
 // 2F800..2FA1F; CJK Compatibility Ideographs Supplement
+// Note: the p > 127 test is not necessary, but optimizes away the ascii case
 #define UNICODE_IS_CJK(p)						\
-    (((p) >= 0x2E80 && (p) <= 0x2EFF)                                   \
-     || ((p) >= 0x3000 && (p) <= 0x9FFF)                                \
-     || ((p) >= 0xA700 && (p) <= 0xA71F)                                \
-     || ((p) >= 0xAC00 && (p) <= 0xD7AF)                                \
-     || ((p) >= 0xF900 && (p) <= 0xFAFF)                                \
-     || ((p) >= 0xFE30 && (p) <= 0xFE4F)                                \
-     || ((p) >= 0xFF00 && (p) <= 0xFFEF)                                \
-     || ((p) >= 0x20000 && (p) <= 0x2A6DF)                              \
-     || ((p) >= 0x2F800 && (p) <= 0x2FA1F))
+    ((p) > 127 &&							\
+     (((p) >= 0x2E80 && (p) <= 0x2EFF) ||				\
+      ((p) >= 0x3000 && (p) <= 0x9FFF) ||				\
+      ((p) >= 0xA700 && (p) <= 0xA71F) ||				\
+      ((p) >= 0xAC00 && (p) <= 0xD7AF) ||				\
+      ((p) >= 0xF900 && (p) <= 0xFAFF) ||				\
+      ((p) >= 0xFE30 && (p) <= 0xFE4F) ||				\
+      ((p) >= 0xFF00 && (p) <= 0xFFEF) ||				\
+      ((p) >= 0x20000 && (p) <= 0x2A6DF) ||				\
+      ((p) >= 0x2F800 && (p) <= 0x2FA1F)))
+
+bool TextSplit::isCJK(int c)
+{
+    return UNICODE_IS_CJK(c);
+}
 
 bool          TextSplit::o_processCJK = true;
 unsigned int  TextSplit::o_CJKNgramLen = 2;
@@ -188,15 +201,17 @@ inline bool TextSplit::emitterm(bool isspan, string &w, int pos,
  * @return true if ok, false for error. Splitting should stop in this case.
  * @param spanerase Set if the current span is at its end. Reset it.
  * @param bp        The current BYTE position in the stream
+ * @param spanemit  This is set for intermediate spans: glue char changed.
  */
-inline bool TextSplit::doemit(bool spanerase, int bp)
+inline bool TextSplit::doemit(bool spanerase, int bp, bool spanemit)
 {
     LOGDEB3(("TextSplit::doemit:spn [%s] sp %d wrdS %d wrdL %d spe %d bp %d\n",
 	     span.c_str(), spanpos, wordStart, wordLen, spanerase, bp));
 
     // Emit span. When splitting for query, we only emit final spans
     bool spanemitted = false;
-    if (spanerase && !(m_flags & TXTS_NOSPANS)) {
+    if (!(m_flags & TXTS_NOSPANS) && 
+	((spanemit && !(m_flags & TXTS_ONLYSPANS)) || spanerase) ) {
 	// Maybe trim at end. These are chars that we would keep inside 
 	// a span, but not at the end
 	while (m_span.length() > 0) {
@@ -261,6 +276,7 @@ bool TextSplit::text_to_words(const string &in)
     m_span.erase();
     m_inNumber = false;
     m_wordStart = m_wordLen = m_prevpos = m_prevlen = m_wordpos = m_spanpos = 0;
+    int curspanglue = 0;
 
     Utf8Iter it(in);
 
@@ -306,6 +322,7 @@ bool TextSplit::text_to_words(const string &in)
 
 	case SPACE:
 	SPACE:
+	    curspanglue = 0;
 	    if (m_wordLen || m_span.length()) {
 		if (!doemit(true, it.getBpos()))
 		    return false;
@@ -327,9 +344,11 @@ bool TextSplit::text_to_words(const string &in)
 		} else {
 		    m_wordStart += it.appendchartostring(m_span);
 		}
+		curspanglue = cc;
 	    } else {
 		if (!doemit(false, it.getBpos()))
 		    return false;
+		curspanglue = cc;
 		m_inNumber = false;
 		m_wordStart += it.appendchartostring(m_span);
 	    }
@@ -341,6 +360,7 @@ bool TextSplit::text_to_words(const string &in)
 		if (whatcc(it[it.getCpos()+1]) != DIGIT)
 		    goto SPACE;
 		m_wordLen += it.appendchartostring(m_span);
+		curspanglue = cc;
 		break;
 	    } else {
 		// If . inside a word, keep it, else, this is whitespace. 
@@ -351,8 +371,13 @@ bool TextSplit::text_to_words(const string &in)
 		// A final comma in a word will be removed by doemit
 		if (cc == '.') {
 		    if (m_wordLen) {
-			if (!doemit(false, it.getBpos()))
+			// Disputable special case: set spanemit to
+			// true when encountering a '.' while spanglue is '_'. Think of
+			// a_b.c Done because to avoid breaking stuff after changing
+			// '_' from wordchar to spanglue
+			if (!doemit(false, it.getBpos(), curspanglue == '_'))
 			    return false;
+			curspanglue = cc;
 			// span length could have been adjusted by trimming
 			// inside doemit
 			if (m_span.length())
@@ -360,6 +385,7 @@ bool TextSplit::text_to_words(const string &in)
 			break;
 		    } else {
 			m_wordStart += it.appendchartostring(m_span);
+			curspanglue = cc;
 			break;
 		    }
 		}
@@ -370,6 +396,16 @@ bool TextSplit::text_to_words(const string &in)
 	    if (m_wordLen) {
 		if (!doemit(false, it.getBpos()))
 		    return false;
+		curspanglue = cc;
+		m_inNumber = false;
+	    }
+	    m_wordStart += it.appendchartostring(m_span);
+	    break;
+	case '_':
+	    if (m_wordLen) {
+		if (!doemit(false, it.getBpos()))
+		    return false;
+		curspanglue = cc;
 		m_inNumber = false;
 	    }
 	    m_wordStart += it.appendchartostring(m_span);
@@ -380,6 +416,7 @@ bool TextSplit::text_to_words(const string &in)
 	    if (m_wordLen) {
 		if (!doemit(false, it.getBpos()))
 		    return false;
+		curspanglue = cc;
 		m_inNumber = false;
 		m_wordStart += it.appendchartostring(m_span);
 	    }
@@ -533,6 +570,102 @@ int TextSplit::countWords(const string& s, TextSplit::Flags flgs)
     return cb.wcnt;
 }
 
+bool TextSplit::hasVisibleWhite(const string &in)
+{
+    setcharclasses();
+    Utf8Iter it(in);
+    for (; !it.eof(); it++) {
+	unsigned int c = *it;
+	LOGDEB3(("TextSplit::hasVisibleWhite: testing 0x%04x\n", c));
+	if (c == (unsigned int)-1) {
+	    LOGERR(("hasVisibleWhite: error while scanning UTF-8 string\n"));
+	    return false;
+	}
+	if (visiblewhite.find(c) != visiblewhite.end())
+	    return true;
+    }
+    return false;
+}
+
+template <class T> bool u8stringToStrings(const string &s, T &tokens)
+{
+    setcharclasses();
+    Utf8Iter it(s);
+
+    string current;
+    tokens.clear();
+    enum states {SPACE, TOKEN, INQUOTE, ESCAPE};
+    states state = SPACE;
+    for (; !it.eof(); it++) {
+	unsigned int c = *it;
+	if (visiblewhite.find(c) != visiblewhite.end()) 
+	    c = ' ';
+	LOGDEB3(("TextSplit::stringToStrings: 0x%04x\n", c));
+	if (c == (unsigned int)-1) {
+	    LOGERR(("TextSplit::stringToStrings: error while "
+		    "scanning UTF-8 string\n"));
+	    return false;
+	}
+
+	switch (c) {
+	    case '"': 
+	    switch(state) {
+	    case SPACE: state = INQUOTE; continue;
+	    case TOKEN: goto push_char;
+	    case ESCAPE: state = INQUOTE; goto push_char;
+	    case INQUOTE: tokens.push_back(current);current.clear();
+		state = SPACE; continue;
+	    }
+	    break;
+	    case '\\': 
+	    switch(state) {
+	    case SPACE: 
+	    case TOKEN: state=TOKEN; goto push_char;
+	    case INQUOTE: state = ESCAPE; continue;
+	    case ESCAPE: state = INQUOTE; goto push_char;
+	    }
+	    break;
+
+	    case ' ': 
+	    case '\t': 
+	    case '\n': 
+	    case '\r': 
+	    switch(state) {
+	      case SPACE: continue;
+	      case TOKEN: tokens.push_back(current); current.clear();
+		state = SPACE; continue; 
+	    case INQUOTE: 
+	    case ESCAPE: goto push_char;
+	    }
+	    break;
+
+	    default:
+	    switch(state) {
+	      case ESCAPE: state = INQUOTE; break;
+	      case SPACE:  state = TOKEN;  break;
+	      case TOKEN: 
+	      case INQUOTE: break;
+	    }
+	push_char:
+	    it.appendchartostring(current);
+	}
+    }
+
+    // End of string. Process residue, and possible error (unfinished quote)
+    switch(state) {
+    case SPACE: break;
+    case TOKEN: tokens.push_back(current); break;
+    case INQUOTE: 
+    case ESCAPE: return false;
+    }
+    return true;
+}
+
+bool TextSplit::stringToStrings(const string &s, list<string> &tokens)
+{
+    return u8stringToStrings<list<string> >(s, tokens);
+}
+
 #else  // TEST driver ->
 
 #include <unistd.h>
