@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: internfile.cpp,v 1.46 2008/10/10 08:04:54 dockes Exp $ (C) 2004 J.F.Dockes";
+static char rcsid[] = "@(#$Id: internfile.cpp,v 1.46 2008-10-10 08:04:54 dockes Exp $ (C) 2004 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -19,6 +19,7 @@ static char rcsid[] = "@(#$Id: internfile.cpp,v 1.46 2008/10/10 08:04:54 dockes
  */
 
 #ifndef TEST_INTERNFILE
+#include "autoconfig.h"
 
 #include <unistd.h>
 #include <fcntl.h>
@@ -102,8 +103,11 @@ static bool uncompressfile(RclConfig *conf, const string& ifn,
     ExecCmd ex;
     int status = ex.doexec(cmd, args, 0, &tfile);
     if (status || tfile.empty()) {
-	LOGERR(("uncompressfile: doexec: failed for [%s] status 0x%x\n", ifn.c_str(), status));
-	rmdir(tdir.c_str());
+	LOGERR(("uncompressfile: doexec: failed for [%s] status 0x%x\n", 
+		ifn.c_str(), status));
+	if (wipedir(tdir.c_str())) {
+	    LOGERR(("uncompressfile: wipedir failed\n"));
+	}
 	return false;
     }
     if (tfile[tfile.length() - 1] == '\n')
@@ -129,7 +133,7 @@ void FileInterner::tmpcleanup()
 //
 // Empty handler on return says that we're in error, this will be
 // processed by the first call to internfile().
-FileInterner::FileInterner(const std::string &f, const struct stat *stp,
+FileInterner::FileInterner(const string &f, const struct stat *stp,
 			   RclConfig *cnf, 
 			   const string& td, const string *imime)
     : m_cfg(cnf), m_fn(f), m_forPreview(imime?true:false), m_tdir(td)
@@ -155,16 +159,24 @@ FileInterner::FileInterner(const std::string &f, const struct stat *stp,
 	// identification, then do the rest with the temp file.
 	list<string>ucmd;
 	if (m_cfg->getUncompressor(l_mime, ucmd)) {
-	    if (!uncompressfile(m_cfg, m_fn, ucmd, m_tdir, m_tfile)) {
-		return;
+	    // Check for compressed size limit
+	    int maxkbs = -1;
+	    if (!m_cfg->getConfParam("compressedfilemaxkbs", &maxkbs) ||
+		maxkbs < 0 || !stp || int(stp->st_size / 1024) < maxkbs) {
+		if (!uncompressfile(m_cfg, m_fn, ucmd, m_tdir, m_tfile)) {
+		    return;
+		}
+		LOGDEB1(("internfile: after ucomp: m_tdir %s, tfile %s\n", 
+			 m_tdir.c_str(), m_tfile.c_str()));
+		m_fn = m_tfile;
+		// Note: still using the original file's stat. right ?
+		l_mime = mimetype(m_fn, stp, m_cfg, usfci);
+		if (l_mime.empty() && imime)
+		    l_mime = *imime;
+	    } else {
+		LOGINFO(("internfile: %s over size limit %d kbs\n",
+			 m_fn.c_str(), maxkbs));
 	    }
-	    LOGDEB1(("internfile: after ucomp: m_tdir %s, tfile %s\n", 
-		    m_tdir.c_str(), m_tfile.c_str()));
-	    m_fn = m_tfile;
-	    // Note: still using the original file's stat. right ?
-	    l_mime = mimetype(m_fn, stp, m_cfg, usfci);
-	    if (l_mime.empty() && imime)
-		l_mime = *imime;
 	}
     }
 
@@ -326,7 +338,12 @@ static const string keytt("title");
 bool FileInterner::dijontorcl(Rcl::Doc& doc)
 {
     Dijon::Filter *df = m_handlers.back();
-    const std::map<std::string, std::string>& docdata = df->get_meta_data();
+    if (df == 0) {
+	//??
+	LOGERR(("FileInterner::dijontorcl: null top handler ??\n"));
+	return false;
+    }
+    const map<string, string>& docdata = df->get_meta_data();
 
     for (map<string,string>::const_iterator it = docdata.begin(); 
 	 it != docdata.end(); it++) {
@@ -346,6 +363,18 @@ bool FileInterner::dijontorcl(Rcl::Doc& doc)
 	doc.meta[Rcl::Doc::keyabs] = doc.meta[keyds];
 	doc.meta.erase(keyds);
     }
+#ifdef RCL_USE_XATTR
+    // Finally set any data possibly coming out of the extended file attributes
+    // these override any values from inside the file.
+    RecollFilter *rf = dynamic_cast<RecollFilter*>(df);
+    if (rf != 0) {
+	const map<string, string>& ffa = rf->getFieldsFromAttrs();
+	for (map<string,string>::const_iterator it = ffa.begin(); 
+	     it != ffa.end(); it++) {
+	    doc.meta[it->first] = it->second;
+	}
+    }
+#endif //RCL_USE_XATTR
     return true;
 }
 
@@ -414,7 +443,7 @@ enum addResols {ADD_OK, ADD_CONTINUE, ADD_BREAK, ADD_ERROR};
 // and possibly add a filter/handler to the stack
 int FileInterner::addHandler()
 {
-    const std::map<std::string, std::string>& docdata = 
+    const map<string, string>& docdata = 
 	m_handlers.back()->get_meta_data();
     string charset, mimetype;
     getKeyValue(docdata, keycs, charset);
@@ -619,7 +648,7 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
 	return FIAgain;
 }
 
-
+// Automatic cleanup of iDocToFile's temp dir
 class DirWiper {
  public:
     string dir;
@@ -637,14 +666,20 @@ class DirWiper {
 // We do the usual internfile stuff: create a temporary directory,
 // then create an interner and call internfile. 
 // We then write the data out of the resulting document into the output file.
-bool FileInterner::idocTempFile(TempFile& otemp, RclConfig *cnf, 
-				const string& fn,
-				const string& ipath,
-				const string& mtype)
+// There are two temporary objects:
+// - The internfile temporary directory gets destroyed before we
+//   return by the DirWiper object
+// - The output temporary file which is held in a reference-counted
+//   object and will be deleted when done with.
+bool FileInterner::idocToFile(TempFile& otemp, const string& tofile,
+			      RclConfig *cnf, 
+			      const string& fn,
+			      const string& ipath,
+			      const string& mtype)
 {
     struct stat st;
     if (stat(fn.c_str(), &st) < 0) {
-	LOGERR(("FileInterner::idocTempFile: can't stat [%s]\n", fn.c_str()));
+	LOGERR(("FileInterner::idocToFile: can't stat [%s]\n", fn.c_str()));
 	return false;
     }
 
@@ -659,29 +694,39 @@ bool FileInterner::idocTempFile(TempFile& otemp, RclConfig *cnf,
     string mipath = ipath;
     Status ret = interner.internfile(doc, mipath);
     if (ret == FileInterner::FIError) {
-	LOGERR(("FileInterner::idocTempFile: internfile() failed\n"));
+	LOGERR(("FileInterner::idocToFile: internfile() failed\n"));
 	return false;
     }
-    TempFile temp(new TempFileInternal(cnf->getSuffixFromMimeType(mtype)));
-    if (!temp->ok()) {
-	LOGERR(("FileInterner::idocTempFile: cannot create temporary file"));
-	return false;
+
+    string filename;
+    TempFile temp;
+    if (tofile.empty()) {
+	TempFile temp1(new TempFileInternal(cnf->getSuffixFromMimeType(mtype)));
+	temp = temp1;
+	if (!temp->ok()) {
+	    LOGERR(("FileInterner::idocToFile: cant create temporary file"));
+	    return false;
+	}
+	filename = temp->filename();
+    } else {
+	filename = tofile;
     }
-    int fd = open(temp->filename(), O_WRONLY);
+    int fd = open(filename.c_str(), O_WRONLY|O_CREAT, 0600);
     if (fd < 0) {
-	LOGERR(("FileInterner::idocTempFile: open(%s) failed errno %d\n",
-		temp->filename(), errno));
+	LOGERR(("FileInterner::idocToFile: open(%s) failed errno %d\n",
+		filename.c_str(), errno));
 	return false;
     }
     const string& dt = doc.text;
     if (write(fd, dt.c_str(), dt.length()) != (int)dt.length()) {
 	close(fd);
-	LOGERR(("FileInterner::idocTempFile: write to %s failed errno %d\n",
-		temp->filename(), errno));
+	LOGERR(("FileInterner::idocToFile: write to %s failed errno %d\n",
+		filename.c_str(), errno));
 	return false;
     }
     close(fd);
-    otemp = temp;
+    if (tofile.empty())
+	otemp = temp;
     return true;
 }
 
