@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: mh_html.cpp,v 1.26 2008/10/03 06:17:46 dockes Exp $ (C) 2005 J.F.Dockes";
+static char rcsid[] = "@(#$Id: mh_html.cpp,v 1.26 2008-10-03 06:17:46 dockes Exp $ (C) 2005 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,7 @@ static char rcsid[] = "@(#$Id: mh_html.cpp,v 1.26 2008/10/03 06:17:46 dockes Exp
 #include "indextext.h"
 #include "mh_html.h"
 #include "smallut.h"
+#include "md5.h"
 
 #include <iostream>
 
@@ -40,6 +41,7 @@ using namespace std;
 bool MimeHandlerHtml::set_document_file(const string &fn)
 {
     LOGDEB0(("textHtmlToDoc: %s\n", fn.c_str()));
+    RecollFilter::set_document_file(fn);
     string otext;
     if (!file_to_string(fn, otext)) {
 	LOGINFO(("textHtmlToDoc: cant read: %s\n", fn.c_str()));
@@ -53,6 +55,12 @@ bool MimeHandlerHtml::set_document_string(const string& htext)
 {
     m_html = htext;
     m_havedoc = true;
+
+    // We want to compute the md5 now because we may modify m_html later
+    string md5, xmd5;
+    MD5String(htext, md5);
+    m_metaData["md5"] = MD5HexPrint(md5, xmd5);
+
     return true;
 }
 
