@@ -17,7 +17,7 @@
 #ifndef _GUIUTILS_H_INCLUDED_
 #define _GUIUTILS_H_INCLUDED_
 /* 
- * @(#$Id: guiutils.h,v 1.29 2008/10/03 08:09:35 dockes Exp $  (C) 2005 Jean-Francois Dockes 
+ * @(#$Id: guiutils.h,v 1.29 2008-10-03 08:09:35 dockes Exp $  (C) 2005 Jean-Francois Dockes 
  *                         jean-francois.dockes@wanadoo.fr
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -67,13 +67,13 @@ class PrefsPack {
     int reslistfontsize;
     // Result list format string
     QString reslistformat;
+    string  creslistformat;
     QString queryStemLang;
     int mainwidth;
     int mainheight;
     int pvwidth; // Preview window geom
     int pvheight;
     int ssearchTyp;
-    QString htmlBrowser;
     bool    useDesktopOpen; // typically xdg-open, instead of mimeview settings
     bool    keepSort; // remember sort status between invocations
     bool    sortActive; // Remembered sort state.
@@ -82,6 +82,7 @@ class PrefsPack {
     bool startWithAdvSearchOpen;
     bool startWithSortToolOpen;
     bool previewHtml;
+    bool collapseDuplicates;
     // Extra query indexes. This are encoded to base64 before storing
     // to the qt settings file to avoid any bin string/ charset conv issues
     list<string> allExtraDbs;
