@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: main.cpp,v 1.70 2008/09/30 12:38:29 dockes Exp $ (C) 2005 J.F.Dockes";
+static char rcsid[] = "@(#$Id: main.cpp,v 1.73 2008-12-17 08:01:40 dockes Exp $ (C) 2005 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -73,8 +73,6 @@ static KCmdLineOptions options[] =
 };
 #endif
 
-const string recoll_datadir = RECOLL_DATADIR;
-
 RclConfig *rclconfig;
 Rcl::Db *rcldb;
 #ifdef RCL_USE_ASPELL
@@ -89,10 +87,15 @@ RclConfig* RclConfig::getMainConfig()
 RclHistory *g_dynconf;
 int recollNeedsExit;
 int startIndexingAfterConfig;
-static string dbdir;
-static RclMain *mainWindow;
+RclMain *mainWindow;
 static string recollsharedir;
 
+void startManual(const string& helpindex)
+{
+    if (mainWindow)
+	mainWindow->startManual(helpindex);
+}
+
 bool maybeOpenDb(string &reason, bool force)
 {
     if (!rcldb) {
@@ -108,10 +111,9 @@ bool maybeOpenDb(string &reason, bool force)
 	LOGDEB(("main: adding [%s]\n", it->c_str()));
 	rcldb->addQueryDb(*it);
     }
-    if (!rcldb->isopen() && !rcldb->open(dbdir, rclconfig->getStopfile(),
-					 Rcl::Db::DbRO)) {
+    if (!rcldb->isopen() && !rcldb->open(Rcl::Db::DbRO)) {
 	reason = "Could not open database in " + 
-	    dbdir + " wait for indexing to complete?";
+	    rclconfig->getDbDir() + " wait for indexing to complete?";
 	return false;
     }
     rcldb->setAbstractParams(-1, prefs.syntAbsLen, prefs.syntAbsCtx);
@@ -232,13 +234,32 @@ int main(int argc, char **argv)
     b1: argc--; argv++;
     }
 
+    // If -q was given, all remaining non-option args are concatenated
+    // to the query. This is for the common case recoll -q x y z to
+    // avoid needing quoting "x y z"
+    if (op_flags & OPT_q)
+	while (argc--) {
+	    question += " ";
+	    question += *argv--;
+	}
+
     // Translation file for Qt
     QTranslator qt( 0 );
     qt.load( QString( "qt_" ) + QTextCodec::locale(), "." );
     app.installTranslator( &qt );
 
+    string reason;
+    rclconfig = recollinit(recollCleanup, sigcleanup, reason, &a_config);
+    if (!rclconfig || !rclconfig->ok()) {
+	QString msg = "Configuration problem: ";
+	msg += QString::fromUtf8(reason.c_str());
+	QMessageBox::critical(0, "Recoll",  msg);
+	exit(1);
+    }
+    //    fprintf(stderr, "recollinit done\n");
+
     // Translations for Recoll
-    string translatdir = path_cat(recoll_datadir, "translations");
+    string translatdir = path_cat(rclconfig->getDatadir(), "translations");
     QTranslator translator( 0 );
     // QTextCodec::locale() returns $LANG
     translator.load( QString("recoll_") + QTextCodec::locale(), 
@@ -247,16 +268,6 @@ int main(int argc, char **argv)
 
     //    fprintf(stderr, "Translations installed\n");
 
-    string reason;
-    rclconfig = recollinit(recollCleanup, sigcleanup, reason, &a_config);
-    if (!rclconfig || !rclconfig->ok()) {
-	QString msg = app.translate("Main", "Configuration problem: ");
-	msg += QString::fromUtf8(reason.c_str());
-	QMessageBox::critical(0, "Recoll",  msg);
-	exit(1);
-    }
-    //    fprintf(stderr, "recollinit done\n");
-
 #ifdef RCL_USE_ASPELL
     aspell = new Aspell(rclconfig);
     aspell->init(reason);
@@ -298,8 +309,8 @@ int main(int argc, char **argv)
 
 	//    }
 #else
-    RclMain w;
-    mainWindow = &w;
+	RclMain w;
+	mainWindow = &w;
 #endif
 
     if (prefs.mainwidth > 100) {
@@ -308,7 +319,8 @@ int main(int argc, char **argv)
     }
 
     mainWindow->sSearch->searchTypCMB->setCurrentItem(prefs.ssearchTyp);
-    dbdir = rclconfig->getDbDir();
+    mainWindow->sSearch->searchTypeChanged(prefs.ssearchTyp);
+    string dbdir = rclconfig->getDbDir();
     if (dbdir.empty()) {
 	// Note: this will have to be replaced by a call to a
 	// configuration buildin dialog for initial configuration
@@ -318,7 +330,7 @@ int main(int argc, char **argv)
 	exit(1);
     }
 
-    rcldb = new Rcl::Db;
+    rcldb = new Rcl::Db(rclconfig);
 
     bool needindexconfig = false;
     if (!maybeOpenDb(reason)) {
