@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: rclmain_w.cpp,v 1.57 2008/10/13 07:57:12 dockes Exp $ (C) 2005 J.F.Dockes";
+static char rcsid[] = "@(#$Id: rclmain_w.cpp,v 1.57 2008-10-13 07:57:12 dockes Exp $ (C) 2005 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -33,12 +33,18 @@ using std::pair;
 
 #include <qapplication.h>
 #include <qmessagebox.h>
+
 #if (QT_VERSION < 0x040000)
 #include <qcstring.h>
 #include <qpopupmenu.h>
 #include <qradiobutton.h>
 #include <qbuttongroup.h>
+#include <qfiledialog.h>
+#else
+#include <q3filedialog.h>
+#define QFileDialog  Q3FileDialog
 #endif
+
 #include <qtabwidget.h>
 #include <qtimer.h>
 #include <qstatusbar.h>
@@ -78,6 +84,7 @@ using std::pair;
 using namespace confgui;
 
 #include "rclmain_w.h"
+#include "rclhelp.h"
 #include "moc_rclmain_w.cpp"
 
 extern "C" int XFlush(void *);
@@ -113,6 +120,9 @@ void RclMain::init()
     spellform = 0;
     m_idxStatusAck = false;
 
+    (void)new HelpClient(this);
+    HelpClient::installMap(this->name(), "RCL.SEARCH.SIMPLE");
+
     // Set the focus to the search terms entry:
     sSearch->queryText->setFocus();
 
@@ -196,6 +206,8 @@ void RclMain::init()
 	    this, SLOT(enablePrevPage(bool)));
     connect(resList, SIGNAL(docEditClicked(int)), 
 	    this, SLOT(startNativeViewer(int)));
+    connect(resList, SIGNAL(docSaveToFileClicked(int)), 
+	    this, SLOT(saveDocToFile(int)));
     connect(resList, SIGNAL(editRequested(Rcl::Doc)), 
 	    this, SLOT(startNativeViewer(Rcl::Doc)));
 
@@ -364,7 +376,6 @@ void RclMain::periodic100()
     // Check if indexing thread done
     if (idxthread_getStatus() != IDXTS_NULL) {
 	// Indexing is stopped
-	statusBar()->message("");
 	fileToggleIndexingAction->setText(tr("Update &Index"));
 	fileToggleIndexingAction->setEnabled(TRUE);
 	if (m_idxStatusAck == false) {
@@ -418,7 +429,7 @@ void RclMain::periodic100()
 		mf = url_encode(status.fn, 0);
 	    }
 	    msg += QString::fromUtf8(mf.c_str());
-	    statusBar()->message(msg);
+	    statusBar()->message(msg, 4000);
 	} else if (toggle == 9) {
 	    statusBar()->message("");
 	}
@@ -471,6 +482,7 @@ void RclMain::startSearch(RefCntr<Rcl::SearchData> sdata)
     sdata->setStemlang(stemLang);
 
     Rcl::Query *query = new Rcl::Query(rcldb);
+    query->setCollapseDuplicates(prefs.collapseDuplicates);
 
     if (!query || !query->setQuery(sdata)) {
 	QMessageBox::warning(0, "Recoll", tr("Can't start query: ") +
@@ -792,7 +804,7 @@ void RclMain::ssearchAddTerm(QString term)
     sSearch->queryText->setEditText(text);
 }
 
-void RclMain::startNativeViewer(int docnum)
+void RclMain::saveDocToFile(int docnum)
 {
     Rcl::Doc doc;
     if (!resList->getDoc(docnum, doc)) {
@@ -801,6 +813,54 @@ void RclMain::startNativeViewer(int docnum)
 				" from database"));
 	return;
     }
+    string fn = urltolocalpath(doc.url);
+    QString s = 
+	QFileDialog::getSaveFileName(path_home().c_str(),
+				     "",  this,
+				     tr("Save file dialog"),
+				     tr("Choose a file name to save under"));
+    string tofile((const char *)s.local8Bit());
+    TempFile temp; // not used
+    if (!FileInterner::idocToFile(temp, tofile, rclconfig, fn, 
+				  doc.ipath, doc.mimetype)) {
+	QMessageBox::warning(0, "Recoll",
+			     tr("Cannot extract document or create "
+				"temporary file"));
+	return;
+    }
+}
+
+/* Look for html browser. We make a special effort for html because it's
+ * used for reading help */
+static bool lookForHtmlBrowser(string &exefile)
+{
+    static const char *htmlbrowserlist = 
+	"opera konqueror firefox mozilla netscape epiphany";
+    list<string> blist;
+    stringToTokens(htmlbrowserlist, blist, " ");
+
+    const char *path = getenv("PATH");
+    if (path == 0)
+	path = "/bin:/usr/bin:/usr/bin/X11:/usr/X11R6/bin:/usr/local/bin";
+
+    // Look for each browser 
+    for (list<string>::const_iterator bit = blist.begin(); 
+	 bit != blist.end(); bit++) {
+	if (ExecCmd::which(*bit, exefile, path)) 
+	    return true;
+    }
+    exefile.clear();
+    return false;
+}
+
+void RclMain::startNativeViewer(int docnum)
+{
+    Rcl::Doc doc;
+    if (!resList->getDoc(docnum, doc)) {
+	QMessageBox::warning(0, "Recoll", tr("Cannot retrieve document info" 
+					     " from database"));
+	return;
+    }
     startNativeViewer(doc);
 }
 
@@ -833,7 +893,8 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
     string cmdpath;
     if (prefs.useDesktopOpen) {
 	// Findfilter searches the recoll filters directory in
-	// addition to the path
+	// addition to the path. We store a copy of xdg-open there, to be 
+	// used as last resort
 	cmdpath = rclconfig->findFilter(lcmd.front());
 	// Substitute path for cmd
 	if (!cmdpath.empty()) {
@@ -845,24 +906,30 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
 	ExecCmd::which(lcmd.front(), cmdpath);
     }
 
+    // Specialcase text/html because of the help browser need
+    if (cmdpath.empty() && !doc.mimetype.compare("text/html")) {
+	if (lookForHtmlBrowser(cmdpath)) {
+	    cmd = cmdpath + " %u";
+	}
+    }
     if (cmdpath.empty()) {
+	QString mt = QString::fromAscii(doc.mimetype.c_str());
 	QString message = tr("The viewer specified in mimeconf for %1: %2"
 			     " is not found.\nDo you want to start the "
 			     " preferences dialog ?")
-	    .arg(QString::fromAscii(doc.mimetype.c_str()))
-	    .arg(QString::fromLocal8Bit(lcmd.front().c_str()));
+	    .arg(mt).arg(QString::fromLocal8Bit(lcmd.front().c_str()));
 
 	switch(QMessageBox::warning(0, "Recoll", message, 
 				    "Yes", "No", 0, 0, 1)) {
 	case 0: 
 	    showUIPrefs();
 	    if (uiprefs)
-		uiprefs->showViewAction();
+		uiprefs->showViewAction(mt);
 	    break;
 	case 1:
-	    
-	    return;
+	    break;
 	}
+	return;
     }
 
     // For files with an ipath, we do things differently depending if the 
@@ -873,12 +940,12 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
     string url;
     rclconfig->setKeyDir(path_getfather(fn));
     if (doc.ipath.empty() || wantsipath) {
-	url = url_encode(doc.url, 7);
+	url = doc.url;
     } else {
 	// There is an ipath and the command does not know about
 	// them. We need a temp file.
 	TempFile temp;
-	if (!FileInterner::idocTempFile(temp, rclconfig, fn, 
+	if (!FileInterner::idocToFile(temp, string(), rclconfig, fn, 
 					doc.ipath, doc.mimetype)) {
 	    QMessageBox::warning(0, "Recoll",
 				 tr("Cannot extract document or create "
@@ -913,16 +980,30 @@ void RclMain::startNativeViewer(Rcl::Doc doc)
 	g_dynconf->enterDoc(fn, doc.ipath);
     // We should actually monitor these processes so that we can
     // delete the temp files when they exit
+    LOGDEB(("Executing: [%s]\n", ncmd.c_str()));
     system(ncmd.c_str());
 }
 
 void RclMain::startManual()
 {
-    QString msg = tr("Starting help browser ");
-    if (prefs.htmlBrowser != QString(""))
-	msg += prefs.htmlBrowser;
-    statusBar()->message(msg, 3000);
-    startHelpBrowser();
+    startManual(string());
+}
+
+void RclMain::startManual(const string& index)
+{
+    Rcl::Doc doc;
+    doc.url = "file://";
+    doc.url = path_cat(doc.url, rclconfig->getDatadir());
+    doc.url = path_cat(doc.url, "doc");
+    doc.url = path_cat(doc.url, "usermanual.html");
+    LOGDEB(("RclMain::startManual: help index is %s\n", 
+	    index.empty()?"(null)":index.c_str()));
+    if (!index.empty()) {
+	doc.url += "#";
+	doc.url += index;
+    }
+    doc.mimetype = "text/html";
+    startNativeViewer(doc);
 }
 
 // Search for document 'like' the selected one. We ask rcldb/xapian to find
@@ -981,10 +1062,12 @@ void RclMain::showDocHistory()
 void RclMain::eraseDocHistory()
 {
     // Clear file storage
-    g_dynconf->eraseAll(RclHistory::docSubkey);
+    if (g_dynconf)
+	g_dynconf->eraseAll(RclHistory::docSubkey);
     // Clear possibly displayed history
-    if (resList->displayingHistory())
+    if (resList->displayingHistory()) {
 	showDocHistory();
+    }
 }
 
 // Called when the uiprefs dialog is ok'd
@@ -1033,3 +1116,4 @@ void RclMain::catgFilter(int id)
     resList->setFilterParams(spec);
     resList->setDocSource();
 }
+
