@@ -84,6 +84,7 @@ public slots:
     virtual void showAboutDialog();
     virtual void showMissingHelpers();
     virtual void startManual();
+    virtual void startManual(const string&);
     virtual void showDocHistory();
     virtual void showExtIdxDialog();
     virtual void showUIPrefs();
@@ -97,6 +98,7 @@ public slots:
     virtual void startPreview(Rcl::Doc doc);
     virtual void startNativeViewer(int docnum);
     virtual void startNativeViewer(Rcl::Doc doc);
+    virtual void saveDocToFile(int docnum);
     virtual void previewNextInTab(Preview *, int sid, int docnum);
     virtual void previewPrevInTab(Preview *, int sid, int docnum);
     virtual void previewExposed(Preview *, int sid, int docnum);
