@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: spell_w.cpp,v 1.11 2007/02/19 16:28:05 dockes Exp $ (C) 2005 J.F.Dockes";
+static char rcsid[] = "@(#$Id: spell_w.cpp,v 1.11 2007-02-19 16:28:05 dockes Exp $ (C) 2005 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -44,6 +44,7 @@ static char rcsid[] = "@(#$Id: spell_w.cpp,v 1.11 2007/02/19 16:28:05 dockes Exp
 #include "spell_w.h"
 #include "guiutils.h"
 #include "rcldb.h"
+#include "rclhelp.h"
 
 #ifdef RCL_USE_ASPELL
 #include "rclaspell.h"
@@ -81,6 +82,9 @@ void SpellW::init()
     }
     stemLangCMB->setEnabled(expTypeCMB->currentItem()==2);
 
+    (void)new HelpClient(this);
+    HelpClient::installMap(this->name(), "RCL.SEARCH.TERMEXPLORER");
+
     // signals and slots connections
     connect(baseWordLE, SIGNAL(textChanged(const QString&)), 
 	    this, SLOT(wordChanged(const QString&)));
