@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: ssearch_w.cpp,v 1.25 2008/10/13 11:46:06 dockes Exp $ (C) 2006 J.F.Dockes";
+static char rcsid[] = "@(#$Id: ssearch_w.cpp,v 1.26 2008-12-05 11:09:31 dockes Exp $ (C) 2006 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -35,6 +35,7 @@ static char rcsid[] = "@(#$Id: ssearch_w.cpp,v 1.25 2008/10/13 11:46:06 dockes E
 #include "refcntr.h"
 #include "textsplit.h"
 #include "wasatorcl.h"
+#include "rclhelp.h"
 
 void SSearch::init()
 {
@@ -53,6 +54,7 @@ void SSearch::init()
     connect(clearqPB, SIGNAL(clicked()), 
 	    queryText->lineEdit(), SLOT(clear()));
     connect(searchPB, SIGNAL(clicked()), this, SLOT(startSimpleSearch()));
+    connect(searchTypCMB, SIGNAL(activated(int)), this, SLOT(searchTypeChanged(int)));
 
 #if QT_VERSION >= 0x040000
     queryText->installEventFilter(this);
@@ -62,7 +64,7 @@ void SSearch::init()
     m_escape = false;
 }
 
-void SSearch::searchTextChanged( const QString & text )
+void SSearch::searchTextChanged(const QString& text)
 {
     if (text.isEmpty()) {
 	searchPB->setEnabled(false);
@@ -74,6 +76,15 @@ void SSearch::searchTextChanged( const QString & text )
     }
 }
 
+void SSearch::searchTypeChanged(int typ)
+{
+    LOGDEB(("Search type now %d\n", typ));
+    if (typ == SST_LANG)
+	HelpClient::installMap(this->name(), "RCL.SEARCH.LANG");
+    else 
+	HelpClient::installMap(this->name(), "RCL.SEARCH.SIMPLE");
+}
+
 void SSearch::startSimpleSearch()
 {
     if (queryText->currentText().length() == 0)
@@ -107,7 +118,7 @@ void SSearch::startSimpleSearch()
 	// If there is no white space inside the query, then the user
 	// certainly means it as a phrase.
 	bool isreallyaphrase = false;
-	if (u8.find_first_of(" \t\r\n") == string::npos)
+	if (!TextSplit::hasVisibleWhite(u8))
 	    isreallyaphrase = true;
 
 	// Maybe add automatic phrase ? For ALL and ANY, and not if
