@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: uiprefs_w.cpp,v 1.26 2008/10/03 08:09:36 dockes Exp $ (C) 2005 J.F.Dockes";
+static char rcsid[] = "@(#$Id: uiprefs_w.cpp,v 1.26 2008-10-03 08:09:36 dockes Exp $ (C) 2005 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -67,7 +67,6 @@ void UIPrefsDialog::init()
 
     connect(viewActionPB, SIGNAL(clicked()), this, SLOT(showViewAction()));
     connect(reslistFontPB, SIGNAL(clicked()), this, SLOT(showFontDialog()));
-    connect(helpBrowserPB, SIGNAL(clicked()), this, SLOT(showBrowserDialog()));
     connect(resetFontPB, SIGNAL(clicked()), this, SLOT(resetReslistFont()));
     connect(extraDbLE,SIGNAL(textChanged(const QString&)), this, 
 	    SLOT(extraDbTextChanged(const QString&)));
@@ -97,6 +96,7 @@ void UIPrefsDialog::setFromPrefs()
 {
     // Entries per result page spinbox
     pageLenSB->setValue(prefs.respagesize);
+    collapseDupsCB->setChecked(prefs.collapseDuplicates);
     maxHLTSB->setValue(prefs.maxhltextmbs);
     autoSearchCB->setChecked(prefs.autoSearchOnWS);
     syntlenSB->setValue(prefs.syntAbsLen);
@@ -122,7 +122,6 @@ void UIPrefsDialog::setFromPrefs()
 			       s.setNum(reslistFontSize));
     }
     rlfTE->setText(prefs.reslistformat);
-    helpBrowserLE->setText(prefs.htmlBrowser);
 
     // Stemming language combobox
     stemLangCMB->clear();
@@ -173,6 +172,7 @@ void UIPrefsDialog::accept()
 {
     prefs.autoSearchOnWS = autoSearchCB->isChecked();
     prefs.respagesize = pageLenSB->value();
+    prefs.collapseDuplicates = collapseDupsCB->isChecked();
     prefs.maxhltextmbs = maxHLTSB->value();
 
     prefs.qtermcolor = qtermColorLE->text();
@@ -190,8 +190,7 @@ void UIPrefsDialog::accept()
 	prefs.reslistformat = prefs.getDfltResListFormat();
 	rlfTE->setText(prefs.reslistformat);
     }
-
-    prefs.htmlBrowser =  helpBrowserLE->text();
+    prefs.creslistformat = (const char*)prefs.reslistformat.utf8();
 
     if (stemLangCMB->currentItem() == 0) {
 	prefs.queryStemLang = "";
@@ -293,17 +292,6 @@ void UIPrefsDialog::resetReslistFont()
 			   QString().setNum(this->font().pointSize()));
 }
 
-void UIPrefsDialog::showBrowserDialog()
-{
-    QString s = QFileDialog::getOpenFileName("/usr",
-					     "",
-					     this,
-					     "open file dialog",
-					     "Choose a file");
-    if (!s.isEmpty()) 
-	helpBrowserLE->setText(s);
-}
-
 void UIPrefsDialog::showViewAction()
 {
     if (m_viewAction== 0) {
@@ -314,6 +302,11 @@ void UIPrefsDialog::showViewAction()
     }
     m_viewAction->show();
 }
+void UIPrefsDialog::showViewAction(const QString& mt)
+{
+    showViewAction();
+    m_viewAction->selectMT(mt);
+}
 
 ////////////////////////////////////////////
 // External / extra search indexes setup
