@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: viewaction_w.cpp,v 1.5 2007/09/08 17:21:49 dockes Exp $ (C) 2006 J.F.Dockes";
+static char rcsid[] = "@(#$Id: viewaction_w.cpp,v 1.5 2007-09-08 17:21:49 dockes Exp $ (C) 2006 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -28,11 +28,13 @@ using namespace std;
 
 #if (QT_VERSION < 0x040000)
 #include <qlistview.h>
+#define QLVEXACTMATCH Qt::ExactMatch
 #else
 #include <q3listview.h>
 #define QListView Q3ListView
 #define QListViewItem Q3ListViewItem
 #define QListViewItemIterator Q3ListViewItemIterator
+#define QLVEXACTMATCH Q3ListView::ExactMatch
 #endif
 
 #include <qmessagebox.h>
@@ -57,7 +59,7 @@ void ViewAction::init()
 #endif
 	   this, SLOT(editAction()));
     fillLists();
-    resize(QSize(450, 250).expandedTo(minimumSizeHint()) );
+    resize(QSize(640, 250).expandedTo(minimumSizeHint()) );
 }
 
 void ViewAction::fillLists()
@@ -74,6 +76,16 @@ void ViewAction::fillLists()
 
 }
 
+void ViewAction::selectMT(const QString& mt)
+{
+    QListViewItem *item =  actionsLV->findItem(mt, 0, QLVEXACTMATCH);
+    if (item) {
+	actionsLV->ensureItemVisible(item);
+	actionsLV->setSelected(item, true);
+	actionsLV->setSelectionAnchor(item);
+    }
+}
+
 // To avoid modifying the listview state from the dbl click signal, as
 // advised by the manual
 void ViewAction::listDblClicked()
