@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: rcldb.cpp,v 1.148 2008/10/07 06:44:23 dockes Exp $ (C) 2004 J.F.Dockes";
+static char rcsid[] = "@(#$Id: rcldb.cpp,v 1.154 2008-12-17 16:19:58 dockes Exp $ (C) 2004 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -44,12 +44,11 @@ using namespace std;
 #include "debuglog.h"
 #include "pathut.h"
 #include "smallut.h"
-#include "pathhash.h"
 #include "utf8iter.h"
 #include "searchdata.h"
 #include "rclquery.h"
 #include "rclquery_p.h"
-
+#include "md5.h"
 
 #ifndef MAX
 #define MAX(A,B) (A>B?A:B)
@@ -58,15 +57,6 @@ using namespace std;
 #define MIN(A,B) (A<B?A:B)
 #endif
 
-// Omega compatible values. We leave a hole for future omega values. Not sure 
-// it makes any sense to keep any level of omega compat given that the index
-// is incompatible anyway.
-enum value_slot {
-    VALUE_LASTMOD = 0,	// 4 byte big endian value - seconds since 1970.
-    VALUE_MD5 = 1,	// 16 byte MD5 checksum of original document.
-    VALUE_SIG = 10      // Doc sig as chosen by app (ex: mtime+size
-};
-
 // Recoll index format version is stored in user metadata. When this change,
 // we can't open the db and will have to reindex.
 static const string RCL_IDX_VERSION_KEY("RCL_IDX_VERSION_KEY");
@@ -142,7 +132,7 @@ static const string keycap("caption");
 bool Db::Native::dbDataToRclDoc(Xapian::docid docid, std::string &data, 
 				Doc &doc, int percent)
 {
-    LOGDEB1(("Db::dbDataToRclDoc: data: %s\n", data.c_str()));
+    LOGDEB0(("Db::dbDataToRclDoc: data: %s\n", data.c_str()));
     ConfSimple parms(&data);
     if (!parms.ok())
 	return false;
@@ -200,7 +190,7 @@ static list<string> noPrefixList(const list<string>& in)
     return out;
 }
 
-//#define DEBUGABSTRACT 
+    //#define DEBUGABSTRACT  1
 #ifdef DEBUGABSTRACT
 #define LOGABS LOGDEB
 #else
@@ -310,6 +300,10 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 	return string();
     }
 
+    // This is used to mark positions overlapped by a multi-word match term
+    const string occupiedmarker("?");
+    const string ellipsis("...");
+
     // Let's go populate
     for (multimap<double, string>::reverse_iterator qit = byQ.rbegin(); 
 	 qit != byQ.rend(); qit++) {
@@ -324,7 +318,10 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 	    LOGABS(("makeAbstract: [%s] %d max occs (coef %.2f)\n", 
 		    qterm.c_str(), maxoccs, q));
 	}
-		
+
+	// The match term may span several words
+	int qtrmwrdcnt = TextSplit::countWords(qterm, TextSplit::TXTS_NOSPANS);
+
 	Xapian::PositionIterator pos;
 	// There may be query terms not in this doc. This raises an
 	// exception when requesting the position list, we catch it.
@@ -333,22 +330,42 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 	    unsigned int occurrences = 0;
 	    for (pos = db.positionlist_begin(docid, qterm); 
 		 pos != db.positionlist_end(docid, qterm); pos++) {
-		unsigned int ipos = *pos;
-		if (ipos < baseTextPosition) // Not in text body
+		int ipos = *pos;
+		if (ipos < int(baseTextPosition)) // Not in text body
 		    continue;
 		LOGABS(("makeAbstract: [%s] at %d occurrences %d maxoccs %d\n",
 			qterm.c_str(), ipos, occurrences, maxoccs));
 		// Remember the term position
 		qtermposs.push_back(ipos);
-		// Add adjacent slots to the set to populate at next step
+
+		// Add adjacent slots to the set to populate at next
+		// step by inserting empty strings. Special provisions
+		// for adding ellipsis and for positions overlapped by
+		// the match term.
 		unsigned int sta = MAX(0, ipos-m_db->m_synthAbsWordCtxLen);
-		unsigned int sto = ipos+m_db->m_synthAbsWordCtxLen;
+		unsigned int sto = ipos + qtrmwrdcnt-1 + 
+		    m_db->m_synthAbsWordCtxLen;
 		for (unsigned int ii = sta; ii <= sto;  ii++) {
-		    if (ii == ipos)
+		    if (ii == (unsigned int)ipos) {
 			sparseDoc[ii] = qterm;
-		    else
+		    } else if (ii > (unsigned int)ipos && 
+			       ii < (unsigned int)ipos + qtrmwrdcnt) {
+			sparseDoc[ii] = occupiedmarker;
+		    } else if (!sparseDoc[ii].compare(ellipsis)) {
+			// For an empty slot, the test has a side
+			// effect of inserting an empty string which
+			// is what we want
 			sparseDoc[ii] = emptys;
+		    }
 		}
+		// Add ... at the end. This may be replaced later by
+		// an overlapping extract. Take care not to replace an
+		// empty string here, we really want an empty slot,
+		// use find()
+		if (sparseDoc.find(sto+1) == sparseDoc.end()) {
+		    sparseDoc[sto+1] = ellipsis;
+		}
+
 		// Limit to allocated occurences and total size
 		if (++occurrences >= maxoccs || 
 		    qtermposs.size() >= maxtotaloccs)
@@ -430,24 +447,23 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 
     LOGDEB(("makeAbstract:%d: extracting\n", chron.millis()));
 
-    // Add "..." at ends of chunks
-    for (vector<unsigned int>::const_iterator pos = qtermposs.begin();
-	 pos != qtermposs.end(); pos++) {
-	unsigned int sto = *pos + m_db->m_synthAbsWordCtxLen;
-
-	// Possibly add a ... at the end of chunk if it's not
-	// overlapping
-	if (sparseDoc.find(sto) != sparseDoc.end() && 
-	    sparseDoc.find(sto+1) == sparseDoc.end())
-	    sparseDoc[sto+1] = "...";
-    }
-
     // Finally build the abstract by walking the map (in order of position)
     string abstract;
+    abstract.reserve(sparseDoc.size() * 10);
+    bool incjk = false;
     for (map<unsigned int, string>::const_iterator it = sparseDoc.begin();
 	 it != sparseDoc.end(); it++) {
 	LOGDEB2(("Abtract:output %u -> [%s]\n", it->first,it->second.c_str()));
-	abstract += it->second + " ";
+	if (!occupiedmarker.compare(it->second))
+	    continue;
+	Utf8Iter uit(it->second);
+	bool newcjk = false;
+	if (TextSplit::isCJK(*uit))
+	    newcjk = true;
+	if (!incjk || (incjk && !newcjk))
+	    abstract += " ";
+	incjk = newcjk;
+	abstract += it->second;
     }
 
     // This happens for docs with no terms (only filename) indexed? I'll fix 
@@ -461,17 +477,16 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 
 /* Rcl::Db methods ///////////////////////////////// */
 
-Db::Db() 
-    : m_ndb(0), m_idxAbsTruncLen(250), m_synthAbsLen(250),
+Db::Db(RclConfig *cfp)
+    : m_ndb(0), m_config(cfp), m_idxAbsTruncLen(250), m_synthAbsLen(250),
       m_synthAbsWordCtxLen(4), m_flushMb(-1), 
       m_curtxtsz(0), m_flushtxtsz(0), m_occtxtsz(0),
       m_maxFsOccupPc(0), m_mode(Db::DbRO)
 {
     m_ndb = new Native(this);
-    RclConfig *config = RclConfig::getMainConfig();
-    if (config) {
-	config->getConfParam("maxfsoccuppc", &m_maxFsOccupPc);
-	config->getConfParam("idxflushmb", &m_flushMb);
+    if (m_config) {
+	m_config->getConfParam("maxfsoccuppc", &m_maxFsOccupPc);
+	m_config->getConfParam("idxflushmb", &m_flushMb);
     }
 }
 
@@ -485,18 +500,19 @@ Db::~Db()
     i_close(true);
 }
 
-    list<string> Db::getStemmerNames()
+list<string> Db::getStemmerNames()
 {
     list<string> res;
     stringToStrings(Xapian::Stem::get_available_languages(), res);
     return res;
 }
 
-bool Db::open(const string& dir, const string &stops, OpenMode mode, 
-	      bool keep_updated)
+bool Db::open(OpenMode mode, bool keep_updated)
 {
-    if (m_ndb == 0)
+    if (m_ndb == 0 || m_config == 0) {
+	m_reason = "Null configuration or Xapian Db";
 	return false;
+    }
     LOGDEB(("Db::open: m_isopen %d m_iswritable %d\n", m_ndb->m_isopen, 
 	    m_ndb->m_iswritable));
 
@@ -505,9 +521,9 @@ bool Db::open(const string& dir, const string &stops, OpenMode mode,
 	if (!close())
 	    return false;
     }
-    if (!stops.empty())
-	m_stops.setFile(stops);
-
+    if (!m_config->getStopfile().empty())
+	m_stops.setFile(m_config->getStopfile());
+    string dir = m_config->getDbDir();
     string ermsg;
     try {
 	switch (mode) {
@@ -623,7 +639,7 @@ bool Db::reOpen()
     if (m_ndb && m_ndb->m_isopen) {
 	if (!close())
 	    return false;
-	if (!open(m_basedir, string(), m_mode, true)) {
+	if (!open(m_mode, true)) {
 	    return false;
 	}
     }
@@ -733,8 +749,7 @@ bool Db::fieldToPrefix(const string& fld, string &pfx)
 	fldToPrefs["tags"] = "K";
     }
 
-    RclConfig *config = RclConfig::getMainConfig();
-    if (config && config->getFieldPrefix(fld, pfx))
+    if (m_config && m_config->getFieldPrefix(fld, pfx))
 	return true;
 
     // No data in rclconfig? Check default values
@@ -769,27 +784,33 @@ private:
 };
 
 // Callback for the document to word splitting class during indexation
-bool mySplitterCB::takeword(const std::string &term, int pos, int, int)
+bool mySplitterCB::takeword(const std::string &_term, int pos, int, int)
 {
 #if 0
-    LOGDEB(("mySplitterCB::takeword:splitCb: [%s]\n", term.c_str()));
-    string printable;
-    if (transcode(term, printable, "UTF-8", "ISO-8859-1")) {
-	LOGDEB(("                                [%s]\n", printable.c_str()));
-    }
+    LOGDEB(("mySplitterCB::takeword:splitCb: [%s]\n", _term.c_str()));
 #endif
+    string term;
+    if (!unacmaybefold(_term, term, "UTF-8", true)) {
+	LOGINFO(("Db::splitter::takeword: unac failed for [%s]\n", _term.c_str()));
+	term.clear();
+	// We don't generate a fatal error because of a bad term
+	return true;
+    }
 
+    if (stops.hasStops() && stops.isStop(term)) {
+	LOGDEB1(("Db: takeword [%s] in stop list\n", term.c_str()));
+	return true;
+    }
+
+    // Compute absolute position (pos is relative to current segment),
+    // and remember relative.
+    curpos = pos;
+    pos += basepos;
     string ermsg;
     try {
-	if (stops.hasStops() && stops.isStop(term)) {
-	    LOGDEB1(("Db: takeword [%s] in stop list\n", term.c_str()));
-	    return true;
-	}
 	// Note: 1 is the within document frequency increment. It would 
 	// be possible to assign different weigths to doc parts (ie title)
 	// by using a higher value
-	curpos = pos;
-	pos += basepos;
 	doc.add_posting(term, pos, 1);
 	if (!prefix.empty()) {
 	    doc.add_posting(prefix + term, pos, 1);
@@ -800,28 +821,6 @@ bool mySplitterCB::takeword(const std::string &term, int pos, int, int)
     return false;
 }
 
-// Unaccent and lowercase data, replace \n\r with spaces
-// Removing crlfs is so that we can use the text in the document data fields.
-// Use unac (with folding extension) for removing accents and casefolding
-//
-// Note that we always return true (but set out to "" on error). We don't
-// want to stop indexation because of a bad string
-bool dumb_string(const string &in, string &out)
-{
-    out.clear();
-    if (in.empty())
-	return true;
-
-    string s1 = neutchars(in, "\n\r");
-    if (!unacmaybefold(s1, out, "UTF-8", true)) {
-	LOGINFO(("dumb_string: unac failed for [%s]\n", in.c_str()));
-	out.clear();
-	// See comment at start of func
-	return true;
-    }
-    return true;
-}
-
 // Let our user set the parameters for abstract processing
 void Db::setAbstractParams(int idxtrunc, int syntlen, int syntctxlen)
 {
@@ -876,14 +875,11 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
     Xapian::Document newdocument;
     mySplitterCB splitData(newdocument, m_stops);
     TextSplit splitter(&splitData);
-    string noacc;
 
     // Split and index file name as document term(s)
     LOGDEB2(("Db::add: split file name [%s]\n", fn.c_str()));
-    if (dumb_string(doc.utf8fn, noacc)) {
-	splitter.text_to_words(noacc);
-	splitData.basepos += splitData.curpos + 100;
-    }
+    splitter.text_to_words(doc.utf8fn);
+    splitData.basepos += splitData.curpos + 100;
 
     // Index textual metadata.  These are all indexed as text with
     // positions, as we may want to do phrase searches with them (this
@@ -903,12 +899,8 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
 	    LOGDEB0(("Db::add: field [%s] pfx [%s]: [%s]\n", 
 		    meta_it->first.c_str(), pfx.c_str(), 
 		    meta_it->second.c_str()));
-	    if (!dumb_string(meta_it->second, noacc)) {
-		LOGERR(("Db::add: dumb_string failed\n"));
-		return false;
-	    }
 	    splitData.setprefix(pfx); // Subject
-	    splitter.text_to_words(noacc);
+	    splitter.text_to_words(meta_it->second);
 	    splitData.setprefix(string());
 	    splitData.basepos += splitData.curpos + 100;
 	}
@@ -921,31 +913,28 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
 
     // Split and index body text
     LOGDEB2(("Db::add: split body\n"));
-    if (!dumb_string(doc.text, noacc)) {
-	LOGERR(("Db::add: dumb_string failed\n"));
-	return false;
-    }
-    splitter.text_to_words(noacc);
+    splitter.text_to_words(doc.text);
 
     ////// Special terms for other metadata. No positions for these.
     // Mime type
     newdocument.add_term("T" + doc.mimetype);
 
-    // Simple file name. This is used for file name searches only. We index
-    // it with a term prefix. utf8fn used to be the full path, but it's now
-    // the simple file name.
+    // Simple file name indexed for file name searches with a term prefix
     // We also add a term for the filename extension if any.
-    if (dumb_string(doc.utf8fn, noacc) && !noacc.empty()) {
-	// We should truncate after extracting the extension, but this is
-	// a pathological case anyway
-	if (noacc.size() > 230)
-	    utf8truncate(noacc, 230);
-	string::size_type pos = noacc.rfind('.');
-	if (pos != string::npos && pos != noacc.length() -1) {
-	    newdocument.add_term(string("XE") + noacc.substr(pos+1));
+    if (!doc.utf8fn.empty()) {
+	string fn;
+	if (unacmaybefold(doc.utf8fn, fn, "UTF-8", true)) {
+	    // We should truncate after extracting the extension, but this is
+	    // a pathological case anyway
+	    if (fn.size() > 230)
+		utf8truncate(fn, 230);
+	    string::size_type pos = fn.rfind('.');
+	    if (pos != string::npos && pos != fn.length() - 1) {
+		newdocument.add_term(string("XE") + fn.substr(pos + 1));
+	    }
+	    fn = string("XSFN") + fn;
+	    newdocument.add_term(fn);
 	}
-	noacc = string("XSFN") + noacc;
-	newdocument.add_term(noacc);
     }
 
     // Udi unique term: this is used for file existence/uptodate
@@ -1043,20 +1032,26 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
     if (!doc.meta[Doc::keyabs].empty())
 	RECORD_APPEND(record, Doc::keyabs, doc.meta[Doc::keyabs]);
 
-    RclConfig *config = RclConfig::getMainConfig();
-    if (config) {
-	const set<string>& stored = config->getStoredFields();
-	for (set<string>::const_iterator it = stored.begin();
-	     it != stored.end(); it++) {
-	    string nm = config->fieldCanon(*it);
-	    if (!doc.meta[*it].empty()) {
-		string value = 
-		    neutchars(truncate_to_word(doc.meta[*it], 150), nc);
-		RECORD_APPEND(record, nm, value);
-	    }
+    const set<string>& stored = m_config->getStoredFields();
+    for (set<string>::const_iterator it = stored.begin();
+	 it != stored.end(); it++) {
+	string nm = m_config->fieldCanon(*it);
+	if (!doc.meta[*it].empty()) {
+	    string value = 
+		neutchars(truncate_to_word(doc.meta[*it], 150), nc);
+	    RECORD_APPEND(record, nm, value);
 	}
     }
 
+    // If the file's md5 was computed, add value. This is optionally
+    // used for query result duplicate elimination.
+    string& md5 = doc.meta[Doc::keymd5];
+    if (!md5.empty()) {
+	string digest;
+	MD5HexScan(md5, digest);
+	newdocument.add_value(VALUE_MD5, digest);
+    }
+
     LOGDEB0(("Rcl::Db::add: new doc record:\n%s\n", record.c_str()));
     newdocument.set_data(record);
 
@@ -1308,7 +1303,10 @@ bool Db::purgeFile(const string &udi)
 bool Db::filenameWildExp(const string& fnexp, list<string>& names)
 {
     string pattern;
-    dumb_string(fnexp, pattern);
+    if (!unacmaybefold(fnexp, pattern, "UTF-8", true)) {
+	LOGERR(("Db::filenameWildExp: unac error for [%s]\n", fnexp.c_str()));
+	return false;
+    }
     names.clear();
 
     // If pattern is not quoted, and has no wildcards, we add * at
@@ -1366,6 +1364,8 @@ bool Db::stemExpand(const string &lang, const string &term,
 	LOGDEB1(("Db::stemExpand: Got %d from %s\n", 
 		 more.size(), it->c_str()));
 	result.insert(result.end(), more.begin(), more.end());
+	if (result.size() >= (unsigned int)max)
+	    break;
     }
     LOGDEB1(("Db:::stemExpand: final count %d \n", result.size()));
     return true;
@@ -1392,7 +1392,10 @@ bool Db::termMatch(MatchType typ, const string &lang,
 
     // Get rid of capitals and accents
     string droot;
-    dumb_string(root, droot);
+    if (!unacmaybefold(root, droot, "UTF-8", true)) {
+	LOGERR(("Db::termMatch: unac failed for [%s]\n", root.c_str()));
+	return false;
+    }
     string nochars = typ == ET_WILD ? wildSpecChars : regSpecChars;
 
     string prefix;
@@ -1598,7 +1601,6 @@ bool Db::getDoc(const string &udi, Doc &doc)
 	Xapian::PostingIterator docid = m_ndb->db.postlist_begin(uniterm);
 	Xapian::Document xdoc = m_ndb->db.get_document(*docid);
 	string data = xdoc.get_data();
-	list<string> terms;
 	return m_ndb->dbDataToRclDoc(*docid, data, doc, 100);
     } XCATCHERROR(ermsg);
     if (!ermsg.empty()) {
