@@ -1,6 +1,6 @@
 #ifndef _rclquery_h_included_
 #define _rclquery_h_included_
-/* @(#$Id: rclquery.h,v 1.6 2008/09/29 11:33:55 dockes Exp $  (C) 2008 J.F.Dockes */
+/* @(#$Id: rclquery.h,v 1.6 2008-09-29 11:33:55 dockes Exp $  (C) 2008 J.F.Dockes */
 /*
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -57,6 +57,9 @@ class Query {
     const string& getSortBy() const {return m_sortField;}
     bool getSortAscending() const {return m_sortAscending;}
 
+    /** Return or filter results with identical content checksum */
+    void setCollapseDuplicates(bool on) {m_collapseDuplicates = on;}
+
     /** Accept data describing the search and query the index. This can
      * be called repeatedly on the same object which gets reinitialized each
      * time.
@@ -90,8 +93,9 @@ private:
     string m_reason; // Error explanation
     Db    *m_db;
     void  *m_sorter;
-    string       m_sortField;
-    bool         m_sortAscending;
+    string m_sortField;
+    bool   m_sortAscending;
+    bool   m_collapseDuplicates;     
     /* Copyconst and assignement private and forbidden */
     Query(const Query &) {}
     Query & operator=(const Query &) {return *this;};
