@@ -16,7 +16,7 @@
  */
 #ifndef _EXECMD_H_INCLUDED_
 #define _EXECMD_H_INCLUDED_
-/* @(#$Id: execmd.h,v 1.12 2007/05/21 13:30:22 dockes Exp $  (C) 2004 J.F.Dockes */
+/* @(#$Id: execmd.h,v 1.12 2007-05-21 13:30:22 dockes Exp $  (C) 2004 J.F.Dockes */
 
 #include <string>
 #include <list>
@@ -125,9 +125,14 @@ class ExecCmd {
 
     /**
      * Utility routine: check if/where a command is found according to the
-     * current PATH
+     * current PATH (or the specified one
+     * @param cmd command name
+     * @param exe on return, executable path name if found
+     * @param path exec seach path to use instead of getenv(PATH)
+     * @return true if found
      */
-    static bool which(const string& cmd, string& path);
+    static bool which(const string& cmd, string& exepath, 
+		      const char* path = 0);
 
  private:
     vector<string>   m_env;
