@@ -40,8 +40,10 @@ public:
 	}
     }
     X *operator->() {return rep;}
+    X *getptr() const {return rep;}
+    const X *getconstptr() const {return rep;}
     int getcnt() const {return pcount ? *pcount : 0;}
-    const X *getptr() const {return rep;}
+    bool isNull() const {return rep == 0;}
 };
 
 
