@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "@(#$Id: smallut.cpp,v 1.34 2008/10/08 16:15:22 dockes Exp $ (C) 2004 J.F.Dockes";
+static char rcsid[] = "@(#$Id: smallut.cpp,v 1.35 2008-11-19 10:06:49 dockes Exp $ (C) 2004 J.F.Dockes";
 #endif
 /*
  *   This program is free software; you can redistribute it and/or modify
@@ -357,17 +357,22 @@ void trimstring(string &s, const char *ws)
 }
 
 // Remove some chars and replace them with spaces
-string neutchars(const string &str, string delims)
+string neutchars(const string &str, const string &chars)
 {
     string out;
+    neutchars(str, out, chars);
+    return out;
+}
+void neutchars(const string &str, string &out, const string& chars)
+{
     string::size_type startPos, pos;
 
     for (pos = 0;;) { 
-        // Skip initial delims, break if this eats all.
-        if ((startPos = str.find_first_not_of(delims, pos)) == string::npos)
+        // Skip initial chars, break if this eats all.
+        if ((startPos = str.find_first_not_of(chars, pos)) == string::npos)
 	    break;
         // Find next delimiter or end of string (end of token)
-        pos = str.find_first_of(delims, startPos);
+        pos = str.find_first_of(chars, startPos);
         // Add token to the output. Note: token cant be empty here
 	if (pos == string::npos) {
 	    out += str.substr(startPos);
@@ -375,7 +380,6 @@ string neutchars(const string &str, string delims)
 	    out += str.substr(startPos, pos - startPos) + " ";
 	}
     }
-    return out;
 }
 
 
@@ -497,6 +501,58 @@ bool pcSubst(const string& in, string& out, map<char, string>& subs)
     return true;
 }
 
+// Convert byte count into unit (KB/MB...) appropriate for display
+string displayableBytes(long size)
+{
+    char sizebuf[30];
+    const char * unit = " B ";
+
+    if (size > 1024 && size < 1024*1024) {
+	unit = " KB ";
+	size /= 1024;
+    } else if (size  >= 1024*1204) {
+	unit = " MB ";
+	size /= (1024*1024);
+    }
+    sprintf(sizebuf, "%ld%s", size, unit);
+    return string(sizebuf);
+}
+
+string breakIntoLines(const string& in, unsigned int ll, 
+		      unsigned int maxlines)
+{
+    string query = in;
+    string oq;
+    unsigned int nlines = 0;
+    while (query.length() > 0) {
+	string ss = query.substr(0, ll);
+	if (ss.length() == ll) {
+	    string::size_type pos = ss.find_last_of(" ");
+	    if (pos == string::npos) {
+		pos = query.find_first_of(" ");
+		if (pos != string::npos)
+		    ss = query.substr(0, pos+1);
+		else 
+		    ss = query;
+	    } else {
+		ss = ss.substr(0, pos+1);
+	    }
+	}
+	// This cant happen, but anyway. Be very sure to avoid an infinite loop
+	if (ss.length() == 0) {
+	    oq = query;
+	    break;
+	}
+	oq += ss + "\n";
+	if (nlines++ >= maxlines) {
+	    oq += " ... \n";
+	    break;
+	}
+	query= query.substr(ss.length());
+    }
+    return oq;
+}
+
 ////////////////////
 // Internal redefinition of system time interface to help with dependancies
 struct m_timespec {
@@ -659,6 +715,8 @@ int main(int argc, char **argv)
 #elif 1
     std::string testit("ligne\ndeuxieme ligne\r3eme ligne\r\n");
     cout << "[" << neutchars(testit, "\r\n") << "]" << endl;
+    string i, o;
+    cout << "neutchars(null) is [" << neutchars(i, "\r\n") << "]" << endl;
 #endif
 
 }
