@@ -16,7 +16,7 @@
  */
 #ifndef _SMALLUT_H_INCLUDED_
 #define _SMALLUT_H_INCLUDED_
-/* @(#$Id: smallut.h,v 1.31 2008/10/08 16:15:22 dockes Exp $  (C) 2004 J.F.Dockes */
+/* @(#$Id: smallut.h,v 1.33 2008-12-05 07:38:07 dockes Exp $  (C) 2004 J.F.Dockes */
 #include <string>
 #include <list>
 #include <vector>
@@ -48,6 +48,9 @@ extern bool samecharset(const string &cs1, const string &cs2);
  *
  * Token delimiter is " \t\n" except inside dquotes. dquote inside
  * dquotes can be escaped with \ etc...
+ * Input is handled a byte at a time, things will work as long as space tab etc.
+ * have the ascii values and can't appear as part of a multibyte char. utf-8 ok
+ * but so are the iso-8859-x and surely others.
  */
 extern bool stringToStrings(const string &s, list<string> &tokens);
 extern bool stringToStrings(const string &s, vector<string> &tokens);
@@ -77,7 +80,8 @@ extern string escapeHtml(const string &in);
 
 /** Replace some chars with spaces (ie: newline chars). This is not utf8-aware
  *  so chars should only contain ascii */
-extern string neutchars(const string &str, string chars);
+extern string neutchars(const string &str, const string &chars);
+extern void neutchars(const string &str, string& out, const string &chars);
 
 /** turn string into something that won't be expanded by a shell. In practise
  * quote with single-quotes and escape internal singlequotes */
@@ -90,6 +94,12 @@ extern string truncate_to_word(const string &input, string::size_type maxlen);
 /** Truncate in place in an utf8-legal way */
 extern void utf8truncate(string &s, int maxlen);
 
+/** Convert byte count into unit (KB/MB...) appropriate for display */
+string displayableBytes(long size);
+
+/** Break big string into lines */
+string breakIntoLines(const string& in, unsigned int ll = 100, 
+		      unsigned int maxlines= 50);
 /** Small utility to substitute printf-like percents cmds in a string */
 bool pcSubst(const string& in, string& out, map<char, string>& subs);
 
